import fs from "fs/promises";
import path from "path";
import matter from "gray-matter";
import { remark } from "remark";
import html from "remark-html";

export async function getPostById(fileDirectory, slug) {
  const directory = path.join(process.cwd(), fileDirectory);
  const fileNames = await fs.readdir(directory);
  const data = await Promise.all(
    fileNames.map(async (fileName) => {
      const fullPath = path.join(fileDirectory, fileName);
      const fileContents = await fs.readFile(fullPath, "utf8");
      const { data, content } = matter(fileContents);
      const processedContent = remark()
        .use(html)
        .processSync(content)
        .toString();

      return {
        markdown: processedContent,
        ...data,
      };
    })
  );

  return data.filter((e) => e.id == slug);
}

export async function getPosts(fileDirectory, page) {
  const directory = path.join(process.cwd(), fileDirectory);
  const fileNames = await fs.readdir(directory);

  const dataPromises = fileNames.map(async (fileName) => {
    const id = fileName.replace(/\.md$/, "");
    const fullPath = path.join(fileDirectory, fileName);
    const fileContents = await fs.readFile(fullPath, "utf8");
    const { data, content } = matter(fileContents);
    return {
      id,
      ...data,
    };
  });

  const data = await Promise.all(dataPromises);
  const itemsPerPage = 6;
  // Calculate the start and end indices for the current page
  const startIndex = (page - 1) * itemsPerPage;
  const endIndex = startIndex + itemsPerPage;
  const slicedData = Array.isArray(data)
    ? data.slice(startIndex, endIndex)
    : [];
  const response = { data: slicedData, total: data?.length, blogs: data };
  return response;
}
